@@ -1,25 +1,16 @@
 package Org::Element::Link;
-BEGIN {
-  $Org::Element::Link::VERSION = '0.16';
-}
-# ABSTRACT: Represent Org hyperlink
 
 use 5.010;
 use locale;
 use Moo;
-extends 'Org::Element::Base';
+extends 'Org::Element';
 
+our $VERSION = '0.17'; # VERSION
 
 has link => (is => 'rw');
-
-
 has description => (is => 'rw');
-
-
 has from_radio_target => (is => 'rw');
 
-
-
 sub as_string {
     my ($self) = @_;
     return $self->_str if defined $self->_str;
@@ -32,6 +23,7 @@ sub as_string {
 }
 
 1;
+# ABSTRACT: Represent Org hyperlink
 
 
 =pod
@@ -42,11 +34,11 @@ Org::Element::Link - Represent Org hyperlink
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 DESCRIPTION
 
-Derived from L<Org::Element::Base>.
+Derived from L<Org::Element>.
 
 =head1 ATTRIBUTES
 
