@@ -1,19 +1,14 @@
 package Org::Element::RadioTarget;
-BEGIN {
-  $Org::Element::RadioTarget::VERSION = '0.16';
-}
-# ABSTRACT: Represent Org radio target
 
 use 5.010;
 use locale;
 use Moo;
-extends 'Org::Element::Base';
+extends 'Org::Element';
 
+our $VERSION = '0.17'; # VERSION
 
 has target => (is => 'rw');
 
-
-
 sub BUILD {
     my ($self, $args) = @_;
     my $pass = $args->{pass} // 1;
@@ -31,6 +26,7 @@ sub as_string {
 }
 
 1;
+# ABSTRACT: Represent Org radio target
 
 
 =pod
@@ -41,11 +37,11 @@ Org::Element::RadioTarget - Represent Org radio target
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 DESCRIPTION
 
-Derived from L<Org::Element::Base>.
+Derived from L<Org::Element>.
 
 =head1 ATTRIBUTES
 
