@@ -1,26 +1,19 @@
 package Org::Element::Text;
-BEGIN {
-  $Org::Element::Text::VERSION = '0.16';
-}
-# ABSTRACT: Represent text
 
 use 5.010;
 use locale;
 use Moo;
-extends 'Org::Element::Base';
+extends 'Org::Element';
 
+our $VERSION = '0.17'; # VERSION
 
 has text => (is => 'rw');
-
-
 has style => (is => 'rw');
 
 our %mu2style = (''=>'', '*'=>'B', '_'=>'U', '/'=>'I',
                  '+'=>'S', '='=>'C', '~'=>'V');
 our %style2mu = reverse(%mu2style);
 
-
-
 sub as_string {
     my ($self) = @_;
     my $muchar = $style2mu{$self->style // ''} // '';
@@ -32,6 +25,7 @@ sub as_string {
 }
 
 1;
+# ABSTRACT: Represent text
 
 
 =pod
@@ -42,11 +36,11 @@ Org::Element::Text - Represent text
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 DESCRIPTION
 
-Derived from L<Org::Element::Base>.
+Derived from L<Org::Element>.
 
 =head1 ATTRIBUTES
 
@@ -77,3 +71,4 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
+
